# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class DensityProfileLayerDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'depth': 'float',
        'thickness': 'float',
        'density': 'float',
        'weight': 'float',
        'comment': 'str',
        'sort_order': 'int'
    }

    attribute_map = {
        'depth': 'Depth',
        'thickness': 'Thickness',
        'density': 'Density',
        'weight': 'Weight',
        'comment': 'Comment',
        'sort_order': 'SortOrder'
    }

    def __init__(self, depth=None, thickness=None, density=None, weight=None, comment=None, sort_order=None):  # noqa: E501
        """DensityProfileLayerDto - a model defined in Swagger"""  # noqa: E501
        self._depth = None
        self._thickness = None
        self._density = None
        self._weight = None
        self._comment = None
        self._sort_order = None
        self.discriminator = None
        if depth is not None:
            self.depth = depth
        if thickness is not None:
            self.thickness = thickness
        if density is not None:
            self.density = density
        if weight is not None:
            self.weight = weight
        if comment is not None:
            self.comment = comment
        if sort_order is not None:
            self.sort_order = sort_order

    @property
    def depth(self):
        """Gets the depth of this DensityProfileLayerDto.  # noqa: E501


        :return: The depth of this DensityProfileLayerDto.  # noqa: E501
        :rtype: float
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """Sets the depth of this DensityProfileLayerDto.


        :param depth: The depth of this DensityProfileLayerDto.  # noqa: E501
        :type: float
        """

        self._depth = depth

    @property
    def thickness(self):
        """Gets the thickness of this DensityProfileLayerDto.  # noqa: E501

        thickness in m  # noqa: E501

        :return: The thickness of this DensityProfileLayerDto.  # noqa: E501
        :rtype: float
        """
        return self._thickness

    @thickness.setter
    def thickness(self, thickness):
        """Sets the thickness of this DensityProfileLayerDto.

        thickness in m  # noqa: E501

        :param thickness: The thickness of this DensityProfileLayerDto.  # noqa: E501
        :type: float
        """

        self._thickness = thickness

    @property
    def density(self):
        """Gets the density of this DensityProfileLayerDto.  # noqa: E501

        Density in kg/m^3  # noqa: E501

        :return: The density of this DensityProfileLayerDto.  # noqa: E501
        :rtype: float
        """
        return self._density

    @density.setter
    def density(self, density):
        """Sets the density of this DensityProfileLayerDto.

        Density in kg/m^3  # noqa: E501

        :param density: The density of this DensityProfileLayerDto.  # noqa: E501
        :type: float
        """

        self._density = density

    @property
    def weight(self):
        """Gets the weight of this DensityProfileLayerDto.  # noqa: E501

        Weight in KG  # noqa: E501

        :return: The weight of this DensityProfileLayerDto.  # noqa: E501
        :rtype: float
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this DensityProfileLayerDto.

        Weight in KG  # noqa: E501

        :param weight: The weight of this DensityProfileLayerDto.  # noqa: E501
        :type: float
        """

        self._weight = weight

    @property
    def comment(self):
        """Gets the comment of this DensityProfileLayerDto.  # noqa: E501


        :return: The comment of this DensityProfileLayerDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this DensityProfileLayerDto.


        :param comment: The comment of this DensityProfileLayerDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def sort_order(self):
        """Gets the sort_order of this DensityProfileLayerDto.  # noqa: E501


        :return: The sort_order of this DensityProfileLayerDto.  # noqa: E501
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this DensityProfileLayerDto.


        :param sort_order: The sort_order of this DensityProfileLayerDto.  # noqa: E501
        :type: int
        """

        self._sort_order = sort_order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DensityProfileLayerDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DensityProfileLayerDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from varsom_regobs_client.api_client import ApiClient


class LocationApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def location_within_radius(self, latitude, longitude, radius, **kwargs):  # noqa: E501
        """location_within_radius  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.location_within_radius(latitude, longitude, radius, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float latitude: (required)
        :param float longitude: (required)
        :param int radius: (required)
        :param list[int] geo_hazard_type_ids:
        :param str observer_guid:
        :param int return_count:
        :return: list[ObsLocationsResponseDtoV2]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.location_within_radius_with_http_info(latitude, longitude, radius, **kwargs)  # noqa: E501
        else:
            (data) = self.location_within_radius_with_http_info(latitude, longitude, radius, **kwargs)  # noqa: E501
            return data

    def location_within_radius_with_http_info(self, latitude, longitude, radius, **kwargs):  # noqa: E501
        """location_within_radius  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.location_within_radius_with_http_info(latitude, longitude, radius, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float latitude: (required)
        :param float longitude: (required)
        :param int radius: (required)
        :param list[int] geo_hazard_type_ids:
        :param str observer_guid:
        :param int return_count:
        :return: list[ObsLocationsResponseDtoV2]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['latitude', 'longitude', 'radius', 'geo_hazard_type_ids', 'observer_guid', 'return_count']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method location_within_radius" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'latitude' is set
        if ('latitude' not in params or
                params['latitude'] is None):
            raise ValueError("Missing the required parameter `latitude` when calling `location_within_radius`")  # noqa: E501
        # verify the required parameter 'longitude' is set
        if ('longitude' not in params or
                params['longitude'] is None):
            raise ValueError("Missing the required parameter `longitude` when calling `location_within_radius`")  # noqa: E501
        # verify the required parameter 'radius' is set
        if ('radius' not in params or
                params['radius'] is None):
            raise ValueError("Missing the required parameter `radius` when calling `location_within_radius`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'latitude' in params:
            query_params.append(('latitude', params['latitude']))  # noqa: E501
        if 'longitude' in params:
            query_params.append(('longitude', params['longitude']))  # noqa: E501
        if 'radius' in params:
            query_params.append(('radius', params['radius']))  # noqa: E501
        if 'geo_hazard_type_ids' in params:
            query_params.append(('geoHazardTypeIds', params['geo_hazard_type_ids']))  # noqa: E501
            collection_formats['geoHazardTypeIds'] = 'multi'  # noqa: E501
        if 'observer_guid' in params:
            query_params.append(('observerGuid', params['observer_guid']))  # noqa: E501
        if 'return_count' in params:
            query_params.append(('returnCount', params['return_count']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Location/WithinRadius', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ObsLocationsResponseDtoV2]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AvalancheEvaluationViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'reg_id': 'int',
        'can_publish': 'bool',
        'avalanche_danger_tid': 'int',
        'avalanche_danger_name': 'str',
        'valid_exposition': 'str',
        'valid_height_relative': 'str',
        'valid_height_from': 'int',
        'valid_heigt_to': 'int',
        'avalanche_problem_tid1': 'int',
        'avalanche_problem_name1': 'str',
        'avalanche_problem_tid2': 'int',
        'avalanche_problem_name2': 'str',
        'avalanche_problem_tid3': 'int',
        'avalanche_problem_name3': 'str',
        'avalanche_evaluation1': 'str',
        'comment': 'str'
    }

    attribute_map = {
        'reg_id': 'RegID',
        'can_publish': 'CanPublish',
        'avalanche_danger_tid': 'AvalancheDangerTID',
        'avalanche_danger_name': 'AvalancheDangerName',
        'valid_exposition': 'ValidExposition',
        'valid_height_relative': 'ValidHeightRelative',
        'valid_height_from': 'ValidHeightFrom',
        'valid_heigt_to': 'ValidHeigtTo',
        'avalanche_problem_tid1': 'AvalancheProblemTID1',
        'avalanche_problem_name1': 'AvalancheProblemName1',
        'avalanche_problem_tid2': 'AvalancheProblemTID2',
        'avalanche_problem_name2': 'AvalancheProblemName2',
        'avalanche_problem_tid3': 'AvalancheProblemTID3',
        'avalanche_problem_name3': 'AvalancheProblemName3',
        'avalanche_evaluation1': 'AvalancheEvaluation1',
        'comment': 'Comment'
    }

    def __init__(self, reg_id=None, can_publish=None, avalanche_danger_tid=None, avalanche_danger_name=None, valid_exposition=None, valid_height_relative=None, valid_height_from=None, valid_heigt_to=None, avalanche_problem_tid1=None, avalanche_problem_name1=None, avalanche_problem_tid2=None, avalanche_problem_name2=None, avalanche_problem_tid3=None, avalanche_problem_name3=None, avalanche_evaluation1=None, comment=None):  # noqa: E501
        """AvalancheEvaluationViewModel - a model defined in Swagger"""  # noqa: E501
        self._reg_id = None
        self._can_publish = None
        self._avalanche_danger_tid = None
        self._avalanche_danger_name = None
        self._valid_exposition = None
        self._valid_height_relative = None
        self._valid_height_from = None
        self._valid_heigt_to = None
        self._avalanche_problem_tid1 = None
        self._avalanche_problem_name1 = None
        self._avalanche_problem_tid2 = None
        self._avalanche_problem_name2 = None
        self._avalanche_problem_tid3 = None
        self._avalanche_problem_name3 = None
        self._avalanche_evaluation1 = None
        self._comment = None
        self.discriminator = None
        if reg_id is not None:
            self.reg_id = reg_id
        if can_publish is not None:
            self.can_publish = can_publish
        if avalanche_danger_tid is not None:
            self.avalanche_danger_tid = avalanche_danger_tid
        if avalanche_danger_name is not None:
            self.avalanche_danger_name = avalanche_danger_name
        if valid_exposition is not None:
            self.valid_exposition = valid_exposition
        if valid_height_relative is not None:
            self.valid_height_relative = valid_height_relative
        if valid_height_from is not None:
            self.valid_height_from = valid_height_from
        if valid_heigt_to is not None:
            self.valid_heigt_to = valid_heigt_to
        if avalanche_problem_tid1 is not None:
            self.avalanche_problem_tid1 = avalanche_problem_tid1
        if avalanche_problem_name1 is not None:
            self.avalanche_problem_name1 = avalanche_problem_name1
        if avalanche_problem_tid2 is not None:
            self.avalanche_problem_tid2 = avalanche_problem_tid2
        if avalanche_problem_name2 is not None:
            self.avalanche_problem_name2 = avalanche_problem_name2
        if avalanche_problem_tid3 is not None:
            self.avalanche_problem_tid3 = avalanche_problem_tid3
        if avalanche_problem_name3 is not None:
            self.avalanche_problem_name3 = avalanche_problem_name3
        if avalanche_evaluation1 is not None:
            self.avalanche_evaluation1 = avalanche_evaluation1
        if comment is not None:
            self.comment = comment

    @property
    def reg_id(self):
        """Gets the reg_id of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The reg_id of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._reg_id

    @reg_id.setter
    def reg_id(self, reg_id):
        """Sets the reg_id of this AvalancheEvaluationViewModel.


        :param reg_id: The reg_id of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: int
        """

        self._reg_id = reg_id

    @property
    def can_publish(self):
        """Gets the can_publish of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The can_publish of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: bool
        """
        return self._can_publish

    @can_publish.setter
    def can_publish(self, can_publish):
        """Sets the can_publish of this AvalancheEvaluationViewModel.


        :param can_publish: The can_publish of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: bool
        """

        self._can_publish = can_publish

    @property
    def avalanche_danger_tid(self):
        """Gets the avalanche_danger_tid of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The avalanche_danger_tid of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_danger_tid

    @avalanche_danger_tid.setter
    def avalanche_danger_tid(self, avalanche_danger_tid):
        """Sets the avalanche_danger_tid of this AvalancheEvaluationViewModel.


        :param avalanche_danger_tid: The avalanche_danger_tid of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: int
        """

        self._avalanche_danger_tid = avalanche_danger_tid

    @property
    def avalanche_danger_name(self):
        """Gets the avalanche_danger_name of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The avalanche_danger_name of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_danger_name

    @avalanche_danger_name.setter
    def avalanche_danger_name(self, avalanche_danger_name):
        """Sets the avalanche_danger_name of this AvalancheEvaluationViewModel.


        :param avalanche_danger_name: The avalanche_danger_name of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: str
        """

        self._avalanche_danger_name = avalanche_danger_name

    @property
    def valid_exposition(self):
        """Gets the valid_exposition of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The valid_exposition of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._valid_exposition

    @valid_exposition.setter
    def valid_exposition(self, valid_exposition):
        """Sets the valid_exposition of this AvalancheEvaluationViewModel.


        :param valid_exposition: The valid_exposition of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: str
        """

        self._valid_exposition = valid_exposition

    @property
    def valid_height_relative(self):
        """Gets the valid_height_relative of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The valid_height_relative of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._valid_height_relative

    @valid_height_relative.setter
    def valid_height_relative(self, valid_height_relative):
        """Sets the valid_height_relative of this AvalancheEvaluationViewModel.


        :param valid_height_relative: The valid_height_relative of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: str
        """

        self._valid_height_relative = valid_height_relative

    @property
    def valid_height_from(self):
        """Gets the valid_height_from of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The valid_height_from of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._valid_height_from

    @valid_height_from.setter
    def valid_height_from(self, valid_height_from):
        """Sets the valid_height_from of this AvalancheEvaluationViewModel.


        :param valid_height_from: The valid_height_from of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: int
        """

        self._valid_height_from = valid_height_from

    @property
    def valid_heigt_to(self):
        """Gets the valid_heigt_to of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The valid_heigt_to of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._valid_heigt_to

    @valid_heigt_to.setter
    def valid_heigt_to(self, valid_heigt_to):
        """Sets the valid_heigt_to of this AvalancheEvaluationViewModel.


        :param valid_heigt_to: The valid_heigt_to of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: int
        """

        self._valid_heigt_to = valid_heigt_to

    @property
    def avalanche_problem_tid1(self):
        """Gets the avalanche_problem_tid1 of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The avalanche_problem_tid1 of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_problem_tid1

    @avalanche_problem_tid1.setter
    def avalanche_problem_tid1(self, avalanche_problem_tid1):
        """Sets the avalanche_problem_tid1 of this AvalancheEvaluationViewModel.


        :param avalanche_problem_tid1: The avalanche_problem_tid1 of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: int
        """

        self._avalanche_problem_tid1 = avalanche_problem_tid1

    @property
    def avalanche_problem_name1(self):
        """Gets the avalanche_problem_name1 of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The avalanche_problem_name1 of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_problem_name1

    @avalanche_problem_name1.setter
    def avalanche_problem_name1(self, avalanche_problem_name1):
        """Sets the avalanche_problem_name1 of this AvalancheEvaluationViewModel.


        :param avalanche_problem_name1: The avalanche_problem_name1 of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: str
        """

        self._avalanche_problem_name1 = avalanche_problem_name1

    @property
    def avalanche_problem_tid2(self):
        """Gets the avalanche_problem_tid2 of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The avalanche_problem_tid2 of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_problem_tid2

    @avalanche_problem_tid2.setter
    def avalanche_problem_tid2(self, avalanche_problem_tid2):
        """Sets the avalanche_problem_tid2 of this AvalancheEvaluationViewModel.


        :param avalanche_problem_tid2: The avalanche_problem_tid2 of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: int
        """

        self._avalanche_problem_tid2 = avalanche_problem_tid2

    @property
    def avalanche_problem_name2(self):
        """Gets the avalanche_problem_name2 of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The avalanche_problem_name2 of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_problem_name2

    @avalanche_problem_name2.setter
    def avalanche_problem_name2(self, avalanche_problem_name2):
        """Sets the avalanche_problem_name2 of this AvalancheEvaluationViewModel.


        :param avalanche_problem_name2: The avalanche_problem_name2 of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: str
        """

        self._avalanche_problem_name2 = avalanche_problem_name2

    @property
    def avalanche_problem_tid3(self):
        """Gets the avalanche_problem_tid3 of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The avalanche_problem_tid3 of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_problem_tid3

    @avalanche_problem_tid3.setter
    def avalanche_problem_tid3(self, avalanche_problem_tid3):
        """Sets the avalanche_problem_tid3 of this AvalancheEvaluationViewModel.


        :param avalanche_problem_tid3: The avalanche_problem_tid3 of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: int
        """

        self._avalanche_problem_tid3 = avalanche_problem_tid3

    @property
    def avalanche_problem_name3(self):
        """Gets the avalanche_problem_name3 of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The avalanche_problem_name3 of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_problem_name3

    @avalanche_problem_name3.setter
    def avalanche_problem_name3(self, avalanche_problem_name3):
        """Sets the avalanche_problem_name3 of this AvalancheEvaluationViewModel.


        :param avalanche_problem_name3: The avalanche_problem_name3 of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: str
        """

        self._avalanche_problem_name3 = avalanche_problem_name3

    @property
    def avalanche_evaluation1(self):
        """Gets the avalanche_evaluation1 of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The avalanche_evaluation1 of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_evaluation1

    @avalanche_evaluation1.setter
    def avalanche_evaluation1(self, avalanche_evaluation1):
        """Sets the avalanche_evaluation1 of this AvalancheEvaluationViewModel.


        :param avalanche_evaluation1: The avalanche_evaluation1 of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: str
        """

        self._avalanche_evaluation1 = avalanche_evaluation1

    @property
    def comment(self):
        """Gets the comment of this AvalancheEvaluationViewModel.  # noqa: E501


        :return: The comment of this AvalancheEvaluationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this AvalancheEvaluationViewModel.


        :param comment: The comment of this AvalancheEvaluationViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AvalancheEvaluationViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AvalancheEvaluationViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class SnowProfileDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment': 'str',
        'is_profile_to_ground': 'bool',
        'snow_temp': 'TempObsDto',
        'strat_profile': 'StratProfileDto',
        'snow_density': 'list[DensityProfileDto]'
    }

    attribute_map = {
        'comment': 'Comment',
        'is_profile_to_ground': 'IsProfileToGround',
        'snow_temp': 'SnowTemp',
        'strat_profile': 'StratProfile',
        'snow_density': 'SnowDensity'
    }

    def __init__(self, comment=None, is_profile_to_ground=None, snow_temp=None, strat_profile=None, snow_density=None):  # noqa: E501
        """SnowProfileDto - a model defined in Swagger"""  # noqa: E501
        self._comment = None
        self._is_profile_to_ground = None
        self._snow_temp = None
        self._strat_profile = None
        self._snow_density = None
        self.discriminator = None
        if comment is not None:
            self.comment = comment
        if is_profile_to_ground is not None:
            self.is_profile_to_ground = is_profile_to_ground
        if snow_temp is not None:
            self.snow_temp = snow_temp
        if strat_profile is not None:
            self.strat_profile = strat_profile
        if snow_density is not None:
            self.snow_density = snow_density

    @property
    def comment(self):
        """Gets the comment of this SnowProfileDto.  # noqa: E501


        :return: The comment of this SnowProfileDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this SnowProfileDto.


        :param comment: The comment of this SnowProfileDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def is_profile_to_ground(self):
        """Gets the is_profile_to_ground of this SnowProfileDto.  # noqa: E501


        :return: The is_profile_to_ground of this SnowProfileDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_profile_to_ground

    @is_profile_to_ground.setter
    def is_profile_to_ground(self, is_profile_to_ground):
        """Sets the is_profile_to_ground of this SnowProfileDto.


        :param is_profile_to_ground: The is_profile_to_ground of this SnowProfileDto.  # noqa: E501
        :type: bool
        """

        self._is_profile_to_ground = is_profile_to_ground

    @property
    def snow_temp(self):
        """Gets the snow_temp of this SnowProfileDto.  # noqa: E501


        :return: The snow_temp of this SnowProfileDto.  # noqa: E501
        :rtype: TempObsDto
        """
        return self._snow_temp

    @snow_temp.setter
    def snow_temp(self, snow_temp):
        """Sets the snow_temp of this SnowProfileDto.


        :param snow_temp: The snow_temp of this SnowProfileDto.  # noqa: E501
        :type: TempObsDto
        """

        self._snow_temp = snow_temp

    @property
    def strat_profile(self):
        """Gets the strat_profile of this SnowProfileDto.  # noqa: E501


        :return: The strat_profile of this SnowProfileDto.  # noqa: E501
        :rtype: StratProfileDto
        """
        return self._strat_profile

    @strat_profile.setter
    def strat_profile(self, strat_profile):
        """Sets the strat_profile of this SnowProfileDto.


        :param strat_profile: The strat_profile of this SnowProfileDto.  # noqa: E501
        :type: StratProfileDto
        """

        self._strat_profile = strat_profile

    @property
    def snow_density(self):
        """Gets the snow_density of this SnowProfileDto.  # noqa: E501


        :return: The snow_density of this SnowProfileDto.  # noqa: E501
        :rtype: list[DensityProfileDto]
        """
        return self._snow_density

    @snow_density.setter
    def snow_density(self, snow_density):
        """Sets the snow_density of this SnowProfileDto.


        :param snow_density: The snow_density of this SnowProfileDto.  # noqa: E501
        :type: list[DensityProfileDto]
        """

        self._snow_density = snow_density

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SnowProfileDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SnowProfileDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class WeatherViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'precipitation_tid': 'int',
        'precipitation_name': 'str',
        'air_temperature': 'float',
        'wind_speed': 'float',
        'wind_direction': 'int',
        'wind_direction_name': 'str',
        'cloud_cover': 'int',
        'comment': 'str'
    }

    attribute_map = {
        'precipitation_tid': 'PrecipitationTID',
        'precipitation_name': 'PrecipitationName',
        'air_temperature': 'AirTemperature',
        'wind_speed': 'WindSpeed',
        'wind_direction': 'WindDirection',
        'wind_direction_name': 'WindDirectionName',
        'cloud_cover': 'CloudCover',
        'comment': 'Comment'
    }

    def __init__(self, precipitation_tid=None, precipitation_name=None, air_temperature=None, wind_speed=None, wind_direction=None, wind_direction_name=None, cloud_cover=None, comment=None):  # noqa: E501
        """WeatherViewModel - a model defined in Swagger"""  # noqa: E501
        self._precipitation_tid = None
        self._precipitation_name = None
        self._air_temperature = None
        self._wind_speed = None
        self._wind_direction = None
        self._wind_direction_name = None
        self._cloud_cover = None
        self._comment = None
        self.discriminator = None
        if precipitation_tid is not None:
            self.precipitation_tid = precipitation_tid
        if precipitation_name is not None:
            self.precipitation_name = precipitation_name
        if air_temperature is not None:
            self.air_temperature = air_temperature
        if wind_speed is not None:
            self.wind_speed = wind_speed
        if wind_direction is not None:
            self.wind_direction = wind_direction
        if wind_direction_name is not None:
            self.wind_direction_name = wind_direction_name
        if cloud_cover is not None:
            self.cloud_cover = cloud_cover
        if comment is not None:
            self.comment = comment

    @property
    def precipitation_tid(self):
        """Gets the precipitation_tid of this WeatherViewModel.  # noqa: E501


        :return: The precipitation_tid of this WeatherViewModel.  # noqa: E501
        :rtype: int
        """
        return self._precipitation_tid

    @precipitation_tid.setter
    def precipitation_tid(self, precipitation_tid):
        """Sets the precipitation_tid of this WeatherViewModel.


        :param precipitation_tid: The precipitation_tid of this WeatherViewModel.  # noqa: E501
        :type: int
        """

        self._precipitation_tid = precipitation_tid

    @property
    def precipitation_name(self):
        """Gets the precipitation_name of this WeatherViewModel.  # noqa: E501


        :return: The precipitation_name of this WeatherViewModel.  # noqa: E501
        :rtype: str
        """
        return self._precipitation_name

    @precipitation_name.setter
    def precipitation_name(self, precipitation_name):
        """Sets the precipitation_name of this WeatherViewModel.


        :param precipitation_name: The precipitation_name of this WeatherViewModel.  # noqa: E501
        :type: str
        """

        self._precipitation_name = precipitation_name

    @property
    def air_temperature(self):
        """Gets the air_temperature of this WeatherViewModel.  # noqa: E501


        :return: The air_temperature of this WeatherViewModel.  # noqa: E501
        :rtype: float
        """
        return self._air_temperature

    @air_temperature.setter
    def air_temperature(self, air_temperature):
        """Sets the air_temperature of this WeatherViewModel.


        :param air_temperature: The air_temperature of this WeatherViewModel.  # noqa: E501
        :type: float
        """

        self._air_temperature = air_temperature

    @property
    def wind_speed(self):
        """Gets the wind_speed of this WeatherViewModel.  # noqa: E501


        :return: The wind_speed of this WeatherViewModel.  # noqa: E501
        :rtype: float
        """
        return self._wind_speed

    @wind_speed.setter
    def wind_speed(self, wind_speed):
        """Sets the wind_speed of this WeatherViewModel.


        :param wind_speed: The wind_speed of this WeatherViewModel.  # noqa: E501
        :type: float
        """

        self._wind_speed = wind_speed

    @property
    def wind_direction(self):
        """Gets the wind_direction of this WeatherViewModel.  # noqa: E501


        :return: The wind_direction of this WeatherViewModel.  # noqa: E501
        :rtype: int
        """
        return self._wind_direction

    @wind_direction.setter
    def wind_direction(self, wind_direction):
        """Sets the wind_direction of this WeatherViewModel.


        :param wind_direction: The wind_direction of this WeatherViewModel.  # noqa: E501
        :type: int
        """

        self._wind_direction = wind_direction

    @property
    def wind_direction_name(self):
        """Gets the wind_direction_name of this WeatherViewModel.  # noqa: E501


        :return: The wind_direction_name of this WeatherViewModel.  # noqa: E501
        :rtype: str
        """
        return self._wind_direction_name

    @wind_direction_name.setter
    def wind_direction_name(self, wind_direction_name):
        """Sets the wind_direction_name of this WeatherViewModel.


        :param wind_direction_name: The wind_direction_name of this WeatherViewModel.  # noqa: E501
        :type: str
        """

        self._wind_direction_name = wind_direction_name

    @property
    def cloud_cover(self):
        """Gets the cloud_cover of this WeatherViewModel.  # noqa: E501


        :return: The cloud_cover of this WeatherViewModel.  # noqa: E501
        :rtype: int
        """
        return self._cloud_cover

    @cloud_cover.setter
    def cloud_cover(self, cloud_cover):
        """Sets the cloud_cover of this WeatherViewModel.


        :param cloud_cover: The cloud_cover of this WeatherViewModel.  # noqa: E501
        :type: int
        """

        self._cloud_cover = cloud_cover

    @property
    def comment(self):
        """Gets the comment of this WeatherViewModel.  # noqa: E501


        :return: The comment of this WeatherViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this WeatherViewModel.


        :param comment: The comment of this WeatherViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WeatherViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WeatherViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from varsom_regobs_client.api.account_api import AccountApi
from varsom_regobs_client.api.attachment_api import AttachmentApi
from varsom_regobs_client.api.general_obs_api import GeneralObsApi
from varsom_regobs_client.api.geo_code_api import GeoCodeApi
from varsom_regobs_client.api.helptext_api import HelptextApi
from varsom_regobs_client.api.kdv_elements_api import KdvElementsApi
from varsom_regobs_client.api.location_api import LocationApi
from varsom_regobs_client.api.registration_api import RegistrationApi
from varsom_regobs_client.api.search_api import SearchApi
from varsom_regobs_client.api.token_api import TokenApi
from varsom_regobs_client.api.trip_api import TripApi



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AtAGlanceViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'reg_id': 'int',
        'geo_hazard_tid': 'int',
        'dt_obs_time': 'datetime',
        'nick_name': 'str',
        'competence_level_tid': 'int',
        'title': 'str',
        'latitude': 'float',
        'longitude': 'float',
        'utm_north': 'int',
        'utm_east': 'int',
        'form_names': 'list[str]',
        'first_attachment_id': 'int'
    }

    attribute_map = {
        'reg_id': 'RegID',
        'geo_hazard_tid': 'GeoHazardTID',
        'dt_obs_time': 'DtObsTime',
        'nick_name': 'NickName',
        'competence_level_tid': 'CompetenceLevelTID',
        'title': 'Title',
        'latitude': 'Latitude',
        'longitude': 'Longitude',
        'utm_north': 'UtmNorth',
        'utm_east': 'UtmEast',
        'form_names': 'FormNames',
        'first_attachment_id': 'FirstAttachmentId'
    }

    def __init__(self, reg_id=None, geo_hazard_tid=None, dt_obs_time=None, nick_name=None, competence_level_tid=None, title=None, latitude=None, longitude=None, utm_north=None, utm_east=None, form_names=None, first_attachment_id=None):  # noqa: E501
        """AtAGlanceViewModel - a model defined in Swagger"""  # noqa: E501
        self._reg_id = None
        self._geo_hazard_tid = None
        self._dt_obs_time = None
        self._nick_name = None
        self._competence_level_tid = None
        self._title = None
        self._latitude = None
        self._longitude = None
        self._utm_north = None
        self._utm_east = None
        self._form_names = None
        self._first_attachment_id = None
        self.discriminator = None
        if reg_id is not None:
            self.reg_id = reg_id
        if geo_hazard_tid is not None:
            self.geo_hazard_tid = geo_hazard_tid
        if dt_obs_time is not None:
            self.dt_obs_time = dt_obs_time
        if nick_name is not None:
            self.nick_name = nick_name
        if competence_level_tid is not None:
            self.competence_level_tid = competence_level_tid
        if title is not None:
            self.title = title
        if latitude is not None:
            self.latitude = latitude
        if longitude is not None:
            self.longitude = longitude
        if utm_north is not None:
            self.utm_north = utm_north
        if utm_east is not None:
            self.utm_east = utm_east
        if form_names is not None:
            self.form_names = form_names
        if first_attachment_id is not None:
            self.first_attachment_id = first_attachment_id

    @property
    def reg_id(self):
        """Gets the reg_id of this AtAGlanceViewModel.  # noqa: E501


        :return: The reg_id of this AtAGlanceViewModel.  # noqa: E501
        :rtype: int
        """
        return self._reg_id

    @reg_id.setter
    def reg_id(self, reg_id):
        """Sets the reg_id of this AtAGlanceViewModel.


        :param reg_id: The reg_id of this AtAGlanceViewModel.  # noqa: E501
        :type: int
        """

        self._reg_id = reg_id

    @property
    def geo_hazard_tid(self):
        """Gets the geo_hazard_tid of this AtAGlanceViewModel.  # noqa: E501


        :return: The geo_hazard_tid of this AtAGlanceViewModel.  # noqa: E501
        :rtype: int
        """
        return self._geo_hazard_tid

    @geo_hazard_tid.setter
    def geo_hazard_tid(self, geo_hazard_tid):
        """Sets the geo_hazard_tid of this AtAGlanceViewModel.


        :param geo_hazard_tid: The geo_hazard_tid of this AtAGlanceViewModel.  # noqa: E501
        :type: int
        """

        self._geo_hazard_tid = geo_hazard_tid

    @property
    def dt_obs_time(self):
        """Gets the dt_obs_time of this AtAGlanceViewModel.  # noqa: E501


        :return: The dt_obs_time of this AtAGlanceViewModel.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_obs_time

    @dt_obs_time.setter
    def dt_obs_time(self, dt_obs_time):
        """Sets the dt_obs_time of this AtAGlanceViewModel.


        :param dt_obs_time: The dt_obs_time of this AtAGlanceViewModel.  # noqa: E501
        :type: datetime
        """

        self._dt_obs_time = dt_obs_time

    @property
    def nick_name(self):
        """Gets the nick_name of this AtAGlanceViewModel.  # noqa: E501


        :return: The nick_name of this AtAGlanceViewModel.  # noqa: E501
        :rtype: str
        """
        return self._nick_name

    @nick_name.setter
    def nick_name(self, nick_name):
        """Sets the nick_name of this AtAGlanceViewModel.


        :param nick_name: The nick_name of this AtAGlanceViewModel.  # noqa: E501
        :type: str
        """

        self._nick_name = nick_name

    @property
    def competence_level_tid(self):
        """Gets the competence_level_tid of this AtAGlanceViewModel.  # noqa: E501


        :return: The competence_level_tid of this AtAGlanceViewModel.  # noqa: E501
        :rtype: int
        """
        return self._competence_level_tid

    @competence_level_tid.setter
    def competence_level_tid(self, competence_level_tid):
        """Sets the competence_level_tid of this AtAGlanceViewModel.


        :param competence_level_tid: The competence_level_tid of this AtAGlanceViewModel.  # noqa: E501
        :type: int
        """

        self._competence_level_tid = competence_level_tid

    @property
    def title(self):
        """Gets the title of this AtAGlanceViewModel.  # noqa: E501


        :return: The title of this AtAGlanceViewModel.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this AtAGlanceViewModel.


        :param title: The title of this AtAGlanceViewModel.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def latitude(self):
        """Gets the latitude of this AtAGlanceViewModel.  # noqa: E501


        :return: The latitude of this AtAGlanceViewModel.  # noqa: E501
        :rtype: float
        """
        return self._latitude

    @latitude.setter
    def latitude(self, latitude):
        """Sets the latitude of this AtAGlanceViewModel.


        :param latitude: The latitude of this AtAGlanceViewModel.  # noqa: E501
        :type: float
        """

        self._latitude = latitude

    @property
    def longitude(self):
        """Gets the longitude of this AtAGlanceViewModel.  # noqa: E501


        :return: The longitude of this AtAGlanceViewModel.  # noqa: E501
        :rtype: float
        """
        return self._longitude

    @longitude.setter
    def longitude(self, longitude):
        """Sets the longitude of this AtAGlanceViewModel.


        :param longitude: The longitude of this AtAGlanceViewModel.  # noqa: E501
        :type: float
        """

        self._longitude = longitude

    @property
    def utm_north(self):
        """Gets the utm_north of this AtAGlanceViewModel.  # noqa: E501


        :return: The utm_north of this AtAGlanceViewModel.  # noqa: E501
        :rtype: int
        """
        return self._utm_north

    @utm_north.setter
    def utm_north(self, utm_north):
        """Sets the utm_north of this AtAGlanceViewModel.


        :param utm_north: The utm_north of this AtAGlanceViewModel.  # noqa: E501
        :type: int
        """

        self._utm_north = utm_north

    @property
    def utm_east(self):
        """Gets the utm_east of this AtAGlanceViewModel.  # noqa: E501


        :return: The utm_east of this AtAGlanceViewModel.  # noqa: E501
        :rtype: int
        """
        return self._utm_east

    @utm_east.setter
    def utm_east(self, utm_east):
        """Sets the utm_east of this AtAGlanceViewModel.


        :param utm_east: The utm_east of this AtAGlanceViewModel.  # noqa: E501
        :type: int
        """

        self._utm_east = utm_east

    @property
    def form_names(self):
        """Gets the form_names of this AtAGlanceViewModel.  # noqa: E501


        :return: The form_names of this AtAGlanceViewModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._form_names

    @form_names.setter
    def form_names(self, form_names):
        """Sets the form_names of this AtAGlanceViewModel.


        :param form_names: The form_names of this AtAGlanceViewModel.  # noqa: E501
        :type: list[str]
        """

        self._form_names = form_names

    @property
    def first_attachment_id(self):
        """Gets the first_attachment_id of this AtAGlanceViewModel.  # noqa: E501


        :return: The first_attachment_id of this AtAGlanceViewModel.  # noqa: E501
        :rtype: int
        """
        return self._first_attachment_id

    @first_attachment_id.setter
    def first_attachment_id(self, first_attachment_id):
        """Sets the first_attachment_id of this AtAGlanceViewModel.


        :param first_attachment_id: The first_attachment_id of this AtAGlanceViewModel.  # noqa: E501
        :type: int
        """

        self._first_attachment_id = first_attachment_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AtAGlanceViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AtAGlanceViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ObserverCompetenceDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'competence_tid': 'int',
        'geohazard_tid': 'int',
        'competence_name': 'str',
        'competence_description': 'str'
    }

    attribute_map = {
        'competence_tid': 'CompetenceTID',
        'geohazard_tid': 'GeohazardTID',
        'competence_name': 'CompetenceName',
        'competence_description': 'CompetenceDescription'
    }

    def __init__(self, competence_tid=None, geohazard_tid=None, competence_name=None, competence_description=None):  # noqa: E501
        """ObserverCompetenceDto - a model defined in Swagger"""  # noqa: E501
        self._competence_tid = None
        self._geohazard_tid = None
        self._competence_name = None
        self._competence_description = None
        self.discriminator = None
        if competence_tid is not None:
            self.competence_tid = competence_tid
        if geohazard_tid is not None:
            self.geohazard_tid = geohazard_tid
        if competence_name is not None:
            self.competence_name = competence_name
        if competence_description is not None:
            self.competence_description = competence_description

    @property
    def competence_tid(self):
        """Gets the competence_tid of this ObserverCompetenceDto.  # noqa: E501


        :return: The competence_tid of this ObserverCompetenceDto.  # noqa: E501
        :rtype: int
        """
        return self._competence_tid

    @competence_tid.setter
    def competence_tid(self, competence_tid):
        """Sets the competence_tid of this ObserverCompetenceDto.


        :param competence_tid: The competence_tid of this ObserverCompetenceDto.  # noqa: E501
        :type: int
        """

        self._competence_tid = competence_tid

    @property
    def geohazard_tid(self):
        """Gets the geohazard_tid of this ObserverCompetenceDto.  # noqa: E501


        :return: The geohazard_tid of this ObserverCompetenceDto.  # noqa: E501
        :rtype: int
        """
        return self._geohazard_tid

    @geohazard_tid.setter
    def geohazard_tid(self, geohazard_tid):
        """Sets the geohazard_tid of this ObserverCompetenceDto.


        :param geohazard_tid: The geohazard_tid of this ObserverCompetenceDto.  # noqa: E501
        :type: int
        """

        self._geohazard_tid = geohazard_tid

    @property
    def competence_name(self):
        """Gets the competence_name of this ObserverCompetenceDto.  # noqa: E501


        :return: The competence_name of this ObserverCompetenceDto.  # noqa: E501
        :rtype: str
        """
        return self._competence_name

    @competence_name.setter
    def competence_name(self, competence_name):
        """Sets the competence_name of this ObserverCompetenceDto.


        :param competence_name: The competence_name of this ObserverCompetenceDto.  # noqa: E501
        :type: str
        """

        self._competence_name = competence_name

    @property
    def competence_description(self):
        """Gets the competence_description of this ObserverCompetenceDto.  # noqa: E501


        :return: The competence_description of this ObserverCompetenceDto.  # noqa: E501
        :rtype: str
        """
        return self._competence_description

    @competence_description.setter
    def competence_description(self, competence_description):
        """Sets the competence_description of this ObserverCompetenceDto.


        :param competence_description: The competence_description of this ObserverCompetenceDto.  # noqa: E501
        :type: str
        """

        self._competence_description = competence_description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ObserverCompetenceDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ObserverCompetenceDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AvalancheEvalProblem2Dto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'avalanche_eval_problem2_id': 'int',
        'avalanche_ext_tid': 'int',
        'aval_probability_tid': 'int',
        'aval_trigger_simple_tid': 'int',
        'destructive_size_tid': 'int',
        'aval_cause_tid': 'int',
        'aval_cause_depth_tid': 'int',
        'aval_cause_attributes': 'int',
        'valid_exposition': 'str',
        'exposed_height1': 'int',
        'exposed_height2': 'int',
        'exposed_height_combo_tid': 'int',
        'aval_propagation_tid': 'int',
        'comment': 'str'
    }

    attribute_map = {
        'avalanche_eval_problem2_id': 'AvalancheEvalProblem2ID',
        'avalanche_ext_tid': 'AvalancheExtTID',
        'aval_probability_tid': 'AvalProbabilityTID',
        'aval_trigger_simple_tid': 'AvalTriggerSimpleTID',
        'destructive_size_tid': 'DestructiveSizeTID',
        'aval_cause_tid': 'AvalCauseTID',
        'aval_cause_depth_tid': 'AvalCauseDepthTID',
        'aval_cause_attributes': 'AvalCauseAttributes',
        'valid_exposition': 'ValidExposition',
        'exposed_height1': 'ExposedHeight1',
        'exposed_height2': 'ExposedHeight2',
        'exposed_height_combo_tid': 'ExposedHeightComboTID',
        'aval_propagation_tid': 'AvalPropagationTID',
        'comment': 'Comment'
    }

    def __init__(self, avalanche_eval_problem2_id=None, avalanche_ext_tid=None, aval_probability_tid=None, aval_trigger_simple_tid=None, destructive_size_tid=None, aval_cause_tid=None, aval_cause_depth_tid=None, aval_cause_attributes=None, valid_exposition=None, exposed_height1=None, exposed_height2=None, exposed_height_combo_tid=None, aval_propagation_tid=None, comment=None):  # noqa: E501
        """AvalancheEvalProblem2Dto - a model defined in Swagger"""  # noqa: E501
        self._avalanche_eval_problem2_id = None
        self._avalanche_ext_tid = None
        self._aval_probability_tid = None
        self._aval_trigger_simple_tid = None
        self._destructive_size_tid = None
        self._aval_cause_tid = None
        self._aval_cause_depth_tid = None
        self._aval_cause_attributes = None
        self._valid_exposition = None
        self._exposed_height1 = None
        self._exposed_height2 = None
        self._exposed_height_combo_tid = None
        self._aval_propagation_tid = None
        self._comment = None
        self.discriminator = None
        if avalanche_eval_problem2_id is not None:
            self.avalanche_eval_problem2_id = avalanche_eval_problem2_id
        if avalanche_ext_tid is not None:
            self.avalanche_ext_tid = avalanche_ext_tid
        if aval_probability_tid is not None:
            self.aval_probability_tid = aval_probability_tid
        if aval_trigger_simple_tid is not None:
            self.aval_trigger_simple_tid = aval_trigger_simple_tid
        if destructive_size_tid is not None:
            self.destructive_size_tid = destructive_size_tid
        if aval_cause_tid is not None:
            self.aval_cause_tid = aval_cause_tid
        if aval_cause_depth_tid is not None:
            self.aval_cause_depth_tid = aval_cause_depth_tid
        if aval_cause_attributes is not None:
            self.aval_cause_attributes = aval_cause_attributes
        if valid_exposition is not None:
            self.valid_exposition = valid_exposition
        if exposed_height1 is not None:
            self.exposed_height1 = exposed_height1
        if exposed_height2 is not None:
            self.exposed_height2 = exposed_height2
        if exposed_height_combo_tid is not None:
            self.exposed_height_combo_tid = exposed_height_combo_tid
        if aval_propagation_tid is not None:
            self.aval_propagation_tid = aval_propagation_tid
        if comment is not None:
            self.comment = comment

    @property
    def avalanche_eval_problem2_id(self):
        """Gets the avalanche_eval_problem2_id of this AvalancheEvalProblem2Dto.  # noqa: E501

        Unik id på denne tabellen da flere er mulig pr RegID.  # noqa: E501

        :return: The avalanche_eval_problem2_id of this AvalancheEvalProblem2Dto.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_eval_problem2_id

    @avalanche_eval_problem2_id.setter
    def avalanche_eval_problem2_id(self, avalanche_eval_problem2_id):
        """Sets the avalanche_eval_problem2_id of this AvalancheEvalProblem2Dto.

        Unik id på denne tabellen da flere er mulig pr RegID.  # noqa: E501

        :param avalanche_eval_problem2_id: The avalanche_eval_problem2_id of this AvalancheEvalProblem2Dto.  # noqa: E501
        :type: int
        """

        self._avalanche_eval_problem2_id = avalanche_eval_problem2_id

    @property
    def avalanche_ext_tid(self):
        """Gets the avalanche_ext_tid of this AvalancheEvalProblem2Dto.  # noqa: E501

        Skredtype. I appen er dette 1. felt under skredproblem. The AvalancheExtKD unique identifier  # noqa: E501

        :return: The avalanche_ext_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_ext_tid

    @avalanche_ext_tid.setter
    def avalanche_ext_tid(self, avalanche_ext_tid):
        """Sets the avalanche_ext_tid of this AvalancheEvalProblem2Dto.

        Skredtype. I appen er dette 1. felt under skredproblem. The AvalancheExtKD unique identifier  # noqa: E501

        :param avalanche_ext_tid: The avalanche_ext_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :type: int
        """

        self._avalanche_ext_tid = avalanche_ext_tid

    @property
    def aval_probability_tid(self):
        """Gets the aval_probability_tid of this AvalancheEvalProblem2Dto.  # noqa: E501

        Sannsynlighet for skred. The AvalProbabilityKD unique identifier  # noqa: E501

        :return: The aval_probability_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :rtype: int
        """
        return self._aval_probability_tid

    @aval_probability_tid.setter
    def aval_probability_tid(self, aval_probability_tid):
        """Sets the aval_probability_tid of this AvalancheEvalProblem2Dto.

        Sannsynlighet for skred. The AvalProbabilityKD unique identifier  # noqa: E501

        :param aval_probability_tid: The aval_probability_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :type: int
        """

        self._aval_probability_tid = aval_probability_tid

    @property
    def aval_trigger_simple_tid(self):
        """Gets the aval_trigger_simple_tid of this AvalancheEvalProblem2Dto.  # noqa: E501

        The AvalTriggerSimpleKD unique identifier  # noqa: E501

        :return: The aval_trigger_simple_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :rtype: int
        """
        return self._aval_trigger_simple_tid

    @aval_trigger_simple_tid.setter
    def aval_trigger_simple_tid(self, aval_trigger_simple_tid):
        """Sets the aval_trigger_simple_tid of this AvalancheEvalProblem2Dto.

        The AvalTriggerSimpleKD unique identifier  # noqa: E501

        :param aval_trigger_simple_tid: The aval_trigger_simple_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :type: int
        """

        self._aval_trigger_simple_tid = aval_trigger_simple_tid

    @property
    def destructive_size_tid(self):
        """Gets the destructive_size_tid of this AvalancheEvalProblem2Dto.  # noqa: E501

        Sannsynlig tilleggsbelastning for å utløse skred. The DestructiveSizeKD unique identifier  # noqa: E501

        :return: The destructive_size_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :rtype: int
        """
        return self._destructive_size_tid

    @destructive_size_tid.setter
    def destructive_size_tid(self, destructive_size_tid):
        """Sets the destructive_size_tid of this AvalancheEvalProblem2Dto.

        Sannsynlig tilleggsbelastning for å utløse skred. The DestructiveSizeKD unique identifier  # noqa: E501

        :param destructive_size_tid: The destructive_size_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :type: int
        """

        self._destructive_size_tid = destructive_size_tid

    @property
    def aval_cause_tid(self):
        """Gets the aval_cause_tid of this AvalancheEvalProblem2Dto.  # noqa: E501

        Hvilket svakt lag løsner skredet på? The AvalCauseKD unique identifier  # noqa: E501

        :return: The aval_cause_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :rtype: int
        """
        return self._aval_cause_tid

    @aval_cause_tid.setter
    def aval_cause_tid(self, aval_cause_tid):
        """Sets the aval_cause_tid of this AvalancheEvalProblem2Dto.

        Hvilket svakt lag løsner skredet på? The AvalCauseKD unique identifier  # noqa: E501

        :param aval_cause_tid: The aval_cause_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :type: int
        """

        self._aval_cause_tid = aval_cause_tid

    @property
    def aval_cause_depth_tid(self):
        """Gets the aval_cause_depth_tid of this AvalancheEvalProblem2Dto.  # noqa: E501

        Hvor dypt ligger det overnevnte svake laget? The AvalCauseDepthKD unique identifier  # noqa: E501

        :return: The aval_cause_depth_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :rtype: int
        """
        return self._aval_cause_depth_tid

    @aval_cause_depth_tid.setter
    def aval_cause_depth_tid(self, aval_cause_depth_tid):
        """Sets the aval_cause_depth_tid of this AvalancheEvalProblem2Dto.

        Hvor dypt ligger det overnevnte svake laget? The AvalCauseDepthKD unique identifier  # noqa: E501

        :param aval_cause_depth_tid: The aval_cause_depth_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :type: int
        """

        self._aval_cause_depth_tid = aval_cause_depth_tid

    @property
    def aval_cause_attributes(self):
        """Gets the aval_cause_attributes of this AvalancheEvalProblem2Dto.  # noqa: E501

        AvalCauseAttributes er flagging. Det som lagres er ugunstige egenskaper til det svake laget i snøen. Dette er flervalgsliste. Om valg 1 og 4 er valgt lagres 9 (binært 1001). Om valg 1 og 2 er valgt lagres 3 (binært 11). Om bare valg 3 er valgt lagres 4 (binært 100)  # noqa: E501

        :return: The aval_cause_attributes of this AvalancheEvalProblem2Dto.  # noqa: E501
        :rtype: int
        """
        return self._aval_cause_attributes

    @aval_cause_attributes.setter
    def aval_cause_attributes(self, aval_cause_attributes):
        """Sets the aval_cause_attributes of this AvalancheEvalProblem2Dto.

        AvalCauseAttributes er flagging. Det som lagres er ugunstige egenskaper til det svake laget i snøen. Dette er flervalgsliste. Om valg 1 og 4 er valgt lagres 9 (binært 1001). Om valg 1 og 2 er valgt lagres 3 (binært 11). Om bare valg 3 er valgt lagres 4 (binært 100)  # noqa: E501

        :param aval_cause_attributes: The aval_cause_attributes of this AvalancheEvalProblem2Dto.  # noqa: E501
        :type: int
        """

        self._aval_cause_attributes = aval_cause_attributes

    @property
    def valid_exposition(self):
        """Gets the valid_exposition of this AvalancheEvalProblem2Dto.  # noqa: E501

        Velg utsatte retninger  # noqa: E501

        :return: The valid_exposition of this AvalancheEvalProblem2Dto.  # noqa: E501
        :rtype: str
        """
        return self._valid_exposition

    @valid_exposition.setter
    def valid_exposition(self, valid_exposition):
        """Sets the valid_exposition of this AvalancheEvalProblem2Dto.

        Velg utsatte retninger  # noqa: E501

        :param valid_exposition: The valid_exposition of this AvalancheEvalProblem2Dto.  # noqa: E501
        :type: str
        """

        self._valid_exposition = valid_exposition

    @property
    def exposed_height1(self):
        """Gets the exposed_height1 of this AvalancheEvalProblem2Dto.  # noqa: E501

        Øverste høyde på “utsatt høyde” symbolet.  # noqa: E501

        :return: The exposed_height1 of this AvalancheEvalProblem2Dto.  # noqa: E501
        :rtype: int
        """
        return self._exposed_height1

    @exposed_height1.setter
    def exposed_height1(self, exposed_height1):
        """Sets the exposed_height1 of this AvalancheEvalProblem2Dto.

        Øverste høyde på “utsatt høyde” symbolet.  # noqa: E501

        :param exposed_height1: The exposed_height1 of this AvalancheEvalProblem2Dto.  # noqa: E501
        :type: int
        """

        self._exposed_height1 = exposed_height1

    @property
    def exposed_height2(self):
        """Gets the exposed_height2 of this AvalancheEvalProblem2Dto.  # noqa: E501

        Nederste høyde på “utsatt høyde” symbolet.  # noqa: E501

        :return: The exposed_height2 of this AvalancheEvalProblem2Dto.  # noqa: E501
        :rtype: int
        """
        return self._exposed_height2

    @exposed_height2.setter
    def exposed_height2(self, exposed_height2):
        """Sets the exposed_height2 of this AvalancheEvalProblem2Dto.

        Nederste høyde på “utsatt høyde” symbolet.  # noqa: E501

        :param exposed_height2: The exposed_height2 of this AvalancheEvalProblem2Dto.  # noqa: E501
        :type: int
        """

        self._exposed_height2 = exposed_height2

    @property
    def exposed_height_combo_tid(self):
        """Gets the exposed_height_combo_tid of this AvalancheEvalProblem2Dto.  # noqa: E501

        Hvilket symbol brukes? Er utsatt tereng over ExposedHeight2 eller under den? The ExposedHeightComboKD unique identifier  # noqa: E501

        :return: The exposed_height_combo_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :rtype: int
        """
        return self._exposed_height_combo_tid

    @exposed_height_combo_tid.setter
    def exposed_height_combo_tid(self, exposed_height_combo_tid):
        """Sets the exposed_height_combo_tid of this AvalancheEvalProblem2Dto.

        Hvilket symbol brukes? Er utsatt tereng over ExposedHeight2 eller under den? The ExposedHeightComboKD unique identifier  # noqa: E501

        :param exposed_height_combo_tid: The exposed_height_combo_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :type: int
        """

        self._exposed_height_combo_tid = exposed_height_combo_tid

    @property
    def aval_propagation_tid(self):
        """Gets the aval_propagation_tid of this AvalancheEvalProblem2Dto.  # noqa: E501

        TODO  # noqa: E501

        :return: The aval_propagation_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :rtype: int
        """
        return self._aval_propagation_tid

    @aval_propagation_tid.setter
    def aval_propagation_tid(self, aval_propagation_tid):
        """Sets the aval_propagation_tid of this AvalancheEvalProblem2Dto.

        TODO  # noqa: E501

        :param aval_propagation_tid: The aval_propagation_tid of this AvalancheEvalProblem2Dto.  # noqa: E501
        :type: int
        """

        self._aval_propagation_tid = aval_propagation_tid

    @property
    def comment(self):
        """Gets the comment of this AvalancheEvalProblem2Dto.  # noqa: E501

        Kommentar til skredproblemet  # noqa: E501

        :return: The comment of this AvalancheEvalProblem2Dto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this AvalancheEvalProblem2Dto.

        Kommentar til skredproblemet  # noqa: E501

        :param comment: The comment of this AvalancheEvalProblem2Dto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AvalancheEvalProblem2Dto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AvalancheEvalProblem2Dto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ObsLocationViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'obs_location_id': 'int',
        'forecast_region_tid': 'int',
        'forecast_region_name': 'str',
        'location_name': 'str',
        'height': 'int',
        'municipal_name': 'str',
        'municipal_no': 'str',
        'country_id': 'int',
        'country_name': 'str',
        'utm_east': 'int',
        'utm_north': 'int',
        'utm_zone': 'int',
        'location_description': 'str',
        'latitude': 'float',
        'longitude': 'float',
        'utm_source_tid': 'int',
        'utm_source_name': 'str',
        'comment': 'str',
        'uncertainty': 'int',
        'title': 'str'
    }

    attribute_map = {
        'obs_location_id': 'ObsLocationID',
        'forecast_region_tid': 'ForecastRegionTID',
        'forecast_region_name': 'ForecastRegionName',
        'location_name': 'LocationName',
        'height': 'Height',
        'municipal_name': 'MunicipalName',
        'municipal_no': 'MunicipalNo',
        'country_id': 'CountryId',
        'country_name': 'CountryName',
        'utm_east': 'UTMEast',
        'utm_north': 'UTMNorth',
        'utm_zone': 'UTMZone',
        'location_description': 'LocationDescription',
        'latitude': 'Latitude',
        'longitude': 'Longitude',
        'utm_source_tid': 'UTMSourceTID',
        'utm_source_name': 'UTMSourceName',
        'comment': 'Comment',
        'uncertainty': 'Uncertainty',
        'title': 'Title'
    }

    def __init__(self, obs_location_id=None, forecast_region_tid=None, forecast_region_name=None, location_name=None, height=None, municipal_name=None, municipal_no=None, country_id=None, country_name=None, utm_east=None, utm_north=None, utm_zone=None, location_description=None, latitude=None, longitude=None, utm_source_tid=None, utm_source_name=None, comment=None, uncertainty=None, title=None):  # noqa: E501
        """ObsLocationViewModel - a model defined in Swagger"""  # noqa: E501
        self._obs_location_id = None
        self._forecast_region_tid = None
        self._forecast_region_name = None
        self._location_name = None
        self._height = None
        self._municipal_name = None
        self._municipal_no = None
        self._country_id = None
        self._country_name = None
        self._utm_east = None
        self._utm_north = None
        self._utm_zone = None
        self._location_description = None
        self._latitude = None
        self._longitude = None
        self._utm_source_tid = None
        self._utm_source_name = None
        self._comment = None
        self._uncertainty = None
        self._title = None
        self.discriminator = None
        if obs_location_id is not None:
            self.obs_location_id = obs_location_id
        if forecast_region_tid is not None:
            self.forecast_region_tid = forecast_region_tid
        if forecast_region_name is not None:
            self.forecast_region_name = forecast_region_name
        if location_name is not None:
            self.location_name = location_name
        if height is not None:
            self.height = height
        if municipal_name is not None:
            self.municipal_name = municipal_name
        if municipal_no is not None:
            self.municipal_no = municipal_no
        if country_id is not None:
            self.country_id = country_id
        if country_name is not None:
            self.country_name = country_name
        if utm_east is not None:
            self.utm_east = utm_east
        if utm_north is not None:
            self.utm_north = utm_north
        if utm_zone is not None:
            self.utm_zone = utm_zone
        if location_description is not None:
            self.location_description = location_description
        if latitude is not None:
            self.latitude = latitude
        if longitude is not None:
            self.longitude = longitude
        if utm_source_tid is not None:
            self.utm_source_tid = utm_source_tid
        if utm_source_name is not None:
            self.utm_source_name = utm_source_name
        if comment is not None:
            self.comment = comment
        if uncertainty is not None:
            self.uncertainty = uncertainty
        if title is not None:
            self.title = title

    @property
    def obs_location_id(self):
        """Gets the obs_location_id of this ObsLocationViewModel.  # noqa: E501


        :return: The obs_location_id of this ObsLocationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._obs_location_id

    @obs_location_id.setter
    def obs_location_id(self, obs_location_id):
        """Sets the obs_location_id of this ObsLocationViewModel.


        :param obs_location_id: The obs_location_id of this ObsLocationViewModel.  # noqa: E501
        :type: int
        """

        self._obs_location_id = obs_location_id

    @property
    def forecast_region_tid(self):
        """Gets the forecast_region_tid of this ObsLocationViewModel.  # noqa: E501


        :return: The forecast_region_tid of this ObsLocationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._forecast_region_tid

    @forecast_region_tid.setter
    def forecast_region_tid(self, forecast_region_tid):
        """Sets the forecast_region_tid of this ObsLocationViewModel.


        :param forecast_region_tid: The forecast_region_tid of this ObsLocationViewModel.  # noqa: E501
        :type: int
        """

        self._forecast_region_tid = forecast_region_tid

    @property
    def forecast_region_name(self):
        """Gets the forecast_region_name of this ObsLocationViewModel.  # noqa: E501


        :return: The forecast_region_name of this ObsLocationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._forecast_region_name

    @forecast_region_name.setter
    def forecast_region_name(self, forecast_region_name):
        """Sets the forecast_region_name of this ObsLocationViewModel.


        :param forecast_region_name: The forecast_region_name of this ObsLocationViewModel.  # noqa: E501
        :type: str
        """

        self._forecast_region_name = forecast_region_name

    @property
    def location_name(self):
        """Gets the location_name of this ObsLocationViewModel.  # noqa: E501


        :return: The location_name of this ObsLocationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._location_name

    @location_name.setter
    def location_name(self, location_name):
        """Sets the location_name of this ObsLocationViewModel.


        :param location_name: The location_name of this ObsLocationViewModel.  # noqa: E501
        :type: str
        """

        self._location_name = location_name

    @property
    def height(self):
        """Gets the height of this ObsLocationViewModel.  # noqa: E501


        :return: The height of this ObsLocationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this ObsLocationViewModel.


        :param height: The height of this ObsLocationViewModel.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def municipal_name(self):
        """Gets the municipal_name of this ObsLocationViewModel.  # noqa: E501


        :return: The municipal_name of this ObsLocationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._municipal_name

    @municipal_name.setter
    def municipal_name(self, municipal_name):
        """Sets the municipal_name of this ObsLocationViewModel.


        :param municipal_name: The municipal_name of this ObsLocationViewModel.  # noqa: E501
        :type: str
        """

        self._municipal_name = municipal_name

    @property
    def municipal_no(self):
        """Gets the municipal_no of this ObsLocationViewModel.  # noqa: E501


        :return: The municipal_no of this ObsLocationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._municipal_no

    @municipal_no.setter
    def municipal_no(self, municipal_no):
        """Sets the municipal_no of this ObsLocationViewModel.


        :param municipal_no: The municipal_no of this ObsLocationViewModel.  # noqa: E501
        :type: str
        """

        self._municipal_no = municipal_no

    @property
    def country_id(self):
        """Gets the country_id of this ObsLocationViewModel.  # noqa: E501


        :return: The country_id of this ObsLocationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._country_id

    @country_id.setter
    def country_id(self, country_id):
        """Sets the country_id of this ObsLocationViewModel.


        :param country_id: The country_id of this ObsLocationViewModel.  # noqa: E501
        :type: int
        """

        self._country_id = country_id

    @property
    def country_name(self):
        """Gets the country_name of this ObsLocationViewModel.  # noqa: E501


        :return: The country_name of this ObsLocationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._country_name

    @country_name.setter
    def country_name(self, country_name):
        """Sets the country_name of this ObsLocationViewModel.


        :param country_name: The country_name of this ObsLocationViewModel.  # noqa: E501
        :type: str
        """

        self._country_name = country_name

    @property
    def utm_east(self):
        """Gets the utm_east of this ObsLocationViewModel.  # noqa: E501


        :return: The utm_east of this ObsLocationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._utm_east

    @utm_east.setter
    def utm_east(self, utm_east):
        """Sets the utm_east of this ObsLocationViewModel.


        :param utm_east: The utm_east of this ObsLocationViewModel.  # noqa: E501
        :type: int
        """

        self._utm_east = utm_east

    @property
    def utm_north(self):
        """Gets the utm_north of this ObsLocationViewModel.  # noqa: E501


        :return: The utm_north of this ObsLocationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._utm_north

    @utm_north.setter
    def utm_north(self, utm_north):
        """Sets the utm_north of this ObsLocationViewModel.


        :param utm_north: The utm_north of this ObsLocationViewModel.  # noqa: E501
        :type: int
        """

        self._utm_north = utm_north

    @property
    def utm_zone(self):
        """Gets the utm_zone of this ObsLocationViewModel.  # noqa: E501


        :return: The utm_zone of this ObsLocationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._utm_zone

    @utm_zone.setter
    def utm_zone(self, utm_zone):
        """Sets the utm_zone of this ObsLocationViewModel.


        :param utm_zone: The utm_zone of this ObsLocationViewModel.  # noqa: E501
        :type: int
        """

        self._utm_zone = utm_zone

    @property
    def location_description(self):
        """Gets the location_description of this ObsLocationViewModel.  # noqa: E501


        :return: The location_description of this ObsLocationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this ObsLocationViewModel.


        :param location_description: The location_description of this ObsLocationViewModel.  # noqa: E501
        :type: str
        """

        self._location_description = location_description

    @property
    def latitude(self):
        """Gets the latitude of this ObsLocationViewModel.  # noqa: E501


        :return: The latitude of this ObsLocationViewModel.  # noqa: E501
        :rtype: float
        """
        return self._latitude

    @latitude.setter
    def latitude(self, latitude):
        """Sets the latitude of this ObsLocationViewModel.


        :param latitude: The latitude of this ObsLocationViewModel.  # noqa: E501
        :type: float
        """

        self._latitude = latitude

    @property
    def longitude(self):
        """Gets the longitude of this ObsLocationViewModel.  # noqa: E501


        :return: The longitude of this ObsLocationViewModel.  # noqa: E501
        :rtype: float
        """
        return self._longitude

    @longitude.setter
    def longitude(self, longitude):
        """Sets the longitude of this ObsLocationViewModel.


        :param longitude: The longitude of this ObsLocationViewModel.  # noqa: E501
        :type: float
        """

        self._longitude = longitude

    @property
    def utm_source_tid(self):
        """Gets the utm_source_tid of this ObsLocationViewModel.  # noqa: E501


        :return: The utm_source_tid of this ObsLocationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._utm_source_tid

    @utm_source_tid.setter
    def utm_source_tid(self, utm_source_tid):
        """Sets the utm_source_tid of this ObsLocationViewModel.


        :param utm_source_tid: The utm_source_tid of this ObsLocationViewModel.  # noqa: E501
        :type: int
        """

        self._utm_source_tid = utm_source_tid

    @property
    def utm_source_name(self):
        """Gets the utm_source_name of this ObsLocationViewModel.  # noqa: E501


        :return: The utm_source_name of this ObsLocationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._utm_source_name

    @utm_source_name.setter
    def utm_source_name(self, utm_source_name):
        """Sets the utm_source_name of this ObsLocationViewModel.


        :param utm_source_name: The utm_source_name of this ObsLocationViewModel.  # noqa: E501
        :type: str
        """

        self._utm_source_name = utm_source_name

    @property
    def comment(self):
        """Gets the comment of this ObsLocationViewModel.  # noqa: E501


        :return: The comment of this ObsLocationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this ObsLocationViewModel.


        :param comment: The comment of this ObsLocationViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def uncertainty(self):
        """Gets the uncertainty of this ObsLocationViewModel.  # noqa: E501


        :return: The uncertainty of this ObsLocationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._uncertainty

    @uncertainty.setter
    def uncertainty(self, uncertainty):
        """Sets the uncertainty of this ObsLocationViewModel.


        :param uncertainty: The uncertainty of this ObsLocationViewModel.  # noqa: E501
        :type: int
        """

        self._uncertainty = uncertainty

    @property
    def title(self):
        """Gets the title of this ObsLocationViewModel.  # noqa: E501


        :return: The title of this ObsLocationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ObsLocationViewModel.


        :param title: The title of this ObsLocationViewModel.  # noqa: E501
        :type: str
        """

        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ObsLocationViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ObsLocationViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import varsom_regobs_client
from models.observer_response_dto import ObserverResponseDto  # noqa: E501
from varsom_regobs_client.rest import ApiException


class TestObserverResponseDto(unittest.TestCase):
    """ObserverResponseDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testObserverResponseDto(self):
        """Test ObserverResponseDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = varsom_regobs_client.models.observer_response_dto.ObserverResponseDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class MyPageData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'guid': 'str',
        'nick_name': 'str',
        'email': 'str',
        'mob_phone_nr': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'work_place': 'str',
        'adrnr': 'int',
        'dt_reg_time': 'datetime',
        'member_of_groups': 'list[ObserverGroupDto]',
        'pending_invitations_to_groups': 'list[ObserverGroupDto]',
        'competence': 'list[ObserverCompetenceDto]',
        'number_of_observations': 'int',
        'main_geohazard_tid': 'int',
        'last_registration_date': 'datetime',
        'default_municipality': 'str'
    }

    attribute_map = {
        'guid': 'Guid',
        'nick_name': 'NickName',
        'email': 'Email',
        'mob_phone_nr': 'MobPhoneNr',
        'first_name': 'FirstName',
        'last_name': 'LastName',
        'work_place': 'WorkPlace',
        'adrnr': 'Adrnr',
        'dt_reg_time': 'DtRegTime',
        'member_of_groups': 'MemberOfGroups',
        'pending_invitations_to_groups': 'PendingInvitationsToGroups',
        'competence': 'Competence',
        'number_of_observations': 'NumberOfObservations',
        'main_geohazard_tid': 'MainGeohazardTID',
        'last_registration_date': 'LastRegistrationDate',
        'default_municipality': 'DefaultMunicipality'
    }

    def __init__(self, guid=None, nick_name=None, email=None, mob_phone_nr=None, first_name=None, last_name=None, work_place=None, adrnr=None, dt_reg_time=None, member_of_groups=None, pending_invitations_to_groups=None, competence=None, number_of_observations=None, main_geohazard_tid=None, last_registration_date=None, default_municipality=None):  # noqa: E501
        """MyPageData - a model defined in Swagger"""  # noqa: E501
        self._guid = None
        self._nick_name = None
        self._email = None
        self._mob_phone_nr = None
        self._first_name = None
        self._last_name = None
        self._work_place = None
        self._adrnr = None
        self._dt_reg_time = None
        self._member_of_groups = None
        self._pending_invitations_to_groups = None
        self._competence = None
        self._number_of_observations = None
        self._main_geohazard_tid = None
        self._last_registration_date = None
        self._default_municipality = None
        self.discriminator = None
        if guid is not None:
            self.guid = guid
        if nick_name is not None:
            self.nick_name = nick_name
        if email is not None:
            self.email = email
        if mob_phone_nr is not None:
            self.mob_phone_nr = mob_phone_nr
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if work_place is not None:
            self.work_place = work_place
        if adrnr is not None:
            self.adrnr = adrnr
        if dt_reg_time is not None:
            self.dt_reg_time = dt_reg_time
        if member_of_groups is not None:
            self.member_of_groups = member_of_groups
        if pending_invitations_to_groups is not None:
            self.pending_invitations_to_groups = pending_invitations_to_groups
        if competence is not None:
            self.competence = competence
        if number_of_observations is not None:
            self.number_of_observations = number_of_observations
        if main_geohazard_tid is not None:
            self.main_geohazard_tid = main_geohazard_tid
        if last_registration_date is not None:
            self.last_registration_date = last_registration_date
        if default_municipality is not None:
            self.default_municipality = default_municipality

    @property
    def guid(self):
        """Gets the guid of this MyPageData.  # noqa: E501


        :return: The guid of this MyPageData.  # noqa: E501
        :rtype: str
        """
        return self._guid

    @guid.setter
    def guid(self, guid):
        """Sets the guid of this MyPageData.


        :param guid: The guid of this MyPageData.  # noqa: E501
        :type: str
        """

        self._guid = guid

    @property
    def nick_name(self):
        """Gets the nick_name of this MyPageData.  # noqa: E501


        :return: The nick_name of this MyPageData.  # noqa: E501
        :rtype: str
        """
        return self._nick_name

    @nick_name.setter
    def nick_name(self, nick_name):
        """Sets the nick_name of this MyPageData.


        :param nick_name: The nick_name of this MyPageData.  # noqa: E501
        :type: str
        """

        self._nick_name = nick_name

    @property
    def email(self):
        """Gets the email of this MyPageData.  # noqa: E501


        :return: The email of this MyPageData.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this MyPageData.


        :param email: The email of this MyPageData.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def mob_phone_nr(self):
        """Gets the mob_phone_nr of this MyPageData.  # noqa: E501


        :return: The mob_phone_nr of this MyPageData.  # noqa: E501
        :rtype: str
        """
        return self._mob_phone_nr

    @mob_phone_nr.setter
    def mob_phone_nr(self, mob_phone_nr):
        """Sets the mob_phone_nr of this MyPageData.


        :param mob_phone_nr: The mob_phone_nr of this MyPageData.  # noqa: E501
        :type: str
        """

        self._mob_phone_nr = mob_phone_nr

    @property
    def first_name(self):
        """Gets the first_name of this MyPageData.  # noqa: E501


        :return: The first_name of this MyPageData.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this MyPageData.


        :param first_name: The first_name of this MyPageData.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this MyPageData.  # noqa: E501


        :return: The last_name of this MyPageData.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this MyPageData.


        :param last_name: The last_name of this MyPageData.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def work_place(self):
        """Gets the work_place of this MyPageData.  # noqa: E501


        :return: The work_place of this MyPageData.  # noqa: E501
        :rtype: str
        """
        return self._work_place

    @work_place.setter
    def work_place(self, work_place):
        """Sets the work_place of this MyPageData.


        :param work_place: The work_place of this MyPageData.  # noqa: E501
        :type: str
        """

        self._work_place = work_place

    @property
    def adrnr(self):
        """Gets the adrnr of this MyPageData.  # noqa: E501


        :return: The adrnr of this MyPageData.  # noqa: E501
        :rtype: int
        """
        return self._adrnr

    @adrnr.setter
    def adrnr(self, adrnr):
        """Sets the adrnr of this MyPageData.


        :param adrnr: The adrnr of this MyPageData.  # noqa: E501
        :type: int
        """

        self._adrnr = adrnr

    @property
    def dt_reg_time(self):
        """Gets the dt_reg_time of this MyPageData.  # noqa: E501


        :return: The dt_reg_time of this MyPageData.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_reg_time

    @dt_reg_time.setter
    def dt_reg_time(self, dt_reg_time):
        """Sets the dt_reg_time of this MyPageData.


        :param dt_reg_time: The dt_reg_time of this MyPageData.  # noqa: E501
        :type: datetime
        """

        self._dt_reg_time = dt_reg_time

    @property
    def member_of_groups(self):
        """Gets the member_of_groups of this MyPageData.  # noqa: E501


        :return: The member_of_groups of this MyPageData.  # noqa: E501
        :rtype: list[ObserverGroupDto]
        """
        return self._member_of_groups

    @member_of_groups.setter
    def member_of_groups(self, member_of_groups):
        """Sets the member_of_groups of this MyPageData.


        :param member_of_groups: The member_of_groups of this MyPageData.  # noqa: E501
        :type: list[ObserverGroupDto]
        """

        self._member_of_groups = member_of_groups

    @property
    def pending_invitations_to_groups(self):
        """Gets the pending_invitations_to_groups of this MyPageData.  # noqa: E501


        :return: The pending_invitations_to_groups of this MyPageData.  # noqa: E501
        :rtype: list[ObserverGroupDto]
        """
        return self._pending_invitations_to_groups

    @pending_invitations_to_groups.setter
    def pending_invitations_to_groups(self, pending_invitations_to_groups):
        """Sets the pending_invitations_to_groups of this MyPageData.


        :param pending_invitations_to_groups: The pending_invitations_to_groups of this MyPageData.  # noqa: E501
        :type: list[ObserverGroupDto]
        """

        self._pending_invitations_to_groups = pending_invitations_to_groups

    @property
    def competence(self):
        """Gets the competence of this MyPageData.  # noqa: E501


        :return: The competence of this MyPageData.  # noqa: E501
        :rtype: list[ObserverCompetenceDto]
        """
        return self._competence

    @competence.setter
    def competence(self, competence):
        """Sets the competence of this MyPageData.


        :param competence: The competence of this MyPageData.  # noqa: E501
        :type: list[ObserverCompetenceDto]
        """

        self._competence = competence

    @property
    def number_of_observations(self):
        """Gets the number_of_observations of this MyPageData.  # noqa: E501


        :return: The number_of_observations of this MyPageData.  # noqa: E501
        :rtype: int
        """
        return self._number_of_observations

    @number_of_observations.setter
    def number_of_observations(self, number_of_observations):
        """Sets the number_of_observations of this MyPageData.


        :param number_of_observations: The number_of_observations of this MyPageData.  # noqa: E501
        :type: int
        """

        self._number_of_observations = number_of_observations

    @property
    def main_geohazard_tid(self):
        """Gets the main_geohazard_tid of this MyPageData.  # noqa: E501


        :return: The main_geohazard_tid of this MyPageData.  # noqa: E501
        :rtype: int
        """
        return self._main_geohazard_tid

    @main_geohazard_tid.setter
    def main_geohazard_tid(self, main_geohazard_tid):
        """Sets the main_geohazard_tid of this MyPageData.


        :param main_geohazard_tid: The main_geohazard_tid of this MyPageData.  # noqa: E501
        :type: int
        """

        self._main_geohazard_tid = main_geohazard_tid

    @property
    def last_registration_date(self):
        """Gets the last_registration_date of this MyPageData.  # noqa: E501


        :return: The last_registration_date of this MyPageData.  # noqa: E501
        :rtype: datetime
        """
        return self._last_registration_date

    @last_registration_date.setter
    def last_registration_date(self, last_registration_date):
        """Sets the last_registration_date of this MyPageData.


        :param last_registration_date: The last_registration_date of this MyPageData.  # noqa: E501
        :type: datetime
        """

        self._last_registration_date = last_registration_date

    @property
    def default_municipality(self):
        """Gets the default_municipality of this MyPageData.  # noqa: E501


        :return: The default_municipality of this MyPageData.  # noqa: E501
        :rtype: str
        """
        return self._default_municipality

    @default_municipality.setter
    def default_municipality(self, default_municipality):
        """Sets the default_municipality of this MyPageData.


        :param default_municipality: The default_municipality of this MyPageData.  # noqa: E501
        :type: str
        """

        self._default_municipality = default_municipality

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MyPageData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MyPageData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class GeoLocationInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'masl': 'int',
        'steepness': 'float',
        'warning_region_id': 'str',
        'warning_region_name': 'str',
        'name': 'str',
        'municipality': 'str',
        'municipality_id': 'str',
        'admin_area_name': 'str',
        'admin_area_id': 'str',
        'country': 'str',
        'country_code': 'str'
    }

    attribute_map = {
        'masl': 'Masl',
        'steepness': 'Steepness',
        'warning_region_id': 'WarningRegionId',
        'warning_region_name': 'WarningRegionName',
        'name': 'Name',
        'municipality': 'Municipality',
        'municipality_id': 'MunicipalityId',
        'admin_area_name': 'AdminAreaName',
        'admin_area_id': 'AdminAreaId',
        'country': 'Country',
        'country_code': 'CountryCode'
    }

    def __init__(self, masl=None, steepness=None, warning_region_id=None, warning_region_name=None, name=None, municipality=None, municipality_id=None, admin_area_name=None, admin_area_id=None, country=None, country_code=None):  # noqa: E501
        """GeoLocationInfo - a model defined in Swagger"""  # noqa: E501
        self._masl = None
        self._steepness = None
        self._warning_region_id = None
        self._warning_region_name = None
        self._name = None
        self._municipality = None
        self._municipality_id = None
        self._admin_area_name = None
        self._admin_area_id = None
        self._country = None
        self._country_code = None
        self.discriminator = None
        if masl is not None:
            self.masl = masl
        if steepness is not None:
            self.steepness = steepness
        if warning_region_id is not None:
            self.warning_region_id = warning_region_id
        if warning_region_name is not None:
            self.warning_region_name = warning_region_name
        if name is not None:
            self.name = name
        if municipality is not None:
            self.municipality = municipality
        if municipality_id is not None:
            self.municipality_id = municipality_id
        if admin_area_name is not None:
            self.admin_area_name = admin_area_name
        if admin_area_id is not None:
            self.admin_area_id = admin_area_id
        if country is not None:
            self.country = country
        if country_code is not None:
            self.country_code = country_code

    @property
    def masl(self):
        """Gets the masl of this GeoLocationInfo.  # noqa: E501


        :return: The masl of this GeoLocationInfo.  # noqa: E501
        :rtype: int
        """
        return self._masl

    @masl.setter
    def masl(self, masl):
        """Sets the masl of this GeoLocationInfo.


        :param masl: The masl of this GeoLocationInfo.  # noqa: E501
        :type: int
        """

        self._masl = masl

    @property
    def steepness(self):
        """Gets the steepness of this GeoLocationInfo.  # noqa: E501


        :return: The steepness of this GeoLocationInfo.  # noqa: E501
        :rtype: float
        """
        return self._steepness

    @steepness.setter
    def steepness(self, steepness):
        """Sets the steepness of this GeoLocationInfo.


        :param steepness: The steepness of this GeoLocationInfo.  # noqa: E501
        :type: float
        """

        self._steepness = steepness

    @property
    def warning_region_id(self):
        """Gets the warning_region_id of this GeoLocationInfo.  # noqa: E501


        :return: The warning_region_id of this GeoLocationInfo.  # noqa: E501
        :rtype: str
        """
        return self._warning_region_id

    @warning_region_id.setter
    def warning_region_id(self, warning_region_id):
        """Sets the warning_region_id of this GeoLocationInfo.


        :param warning_region_id: The warning_region_id of this GeoLocationInfo.  # noqa: E501
        :type: str
        """

        self._warning_region_id = warning_region_id

    @property
    def warning_region_name(self):
        """Gets the warning_region_name of this GeoLocationInfo.  # noqa: E501


        :return: The warning_region_name of this GeoLocationInfo.  # noqa: E501
        :rtype: str
        """
        return self._warning_region_name

    @warning_region_name.setter
    def warning_region_name(self, warning_region_name):
        """Sets the warning_region_name of this GeoLocationInfo.


        :param warning_region_name: The warning_region_name of this GeoLocationInfo.  # noqa: E501
        :type: str
        """

        self._warning_region_name = warning_region_name

    @property
    def name(self):
        """Gets the name of this GeoLocationInfo.  # noqa: E501


        :return: The name of this GeoLocationInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GeoLocationInfo.


        :param name: The name of this GeoLocationInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def municipality(self):
        """Gets the municipality of this GeoLocationInfo.  # noqa: E501


        :return: The municipality of this GeoLocationInfo.  # noqa: E501
        :rtype: str
        """
        return self._municipality

    @municipality.setter
    def municipality(self, municipality):
        """Sets the municipality of this GeoLocationInfo.


        :param municipality: The municipality of this GeoLocationInfo.  # noqa: E501
        :type: str
        """

        self._municipality = municipality

    @property
    def municipality_id(self):
        """Gets the municipality_id of this GeoLocationInfo.  # noqa: E501


        :return: The municipality_id of this GeoLocationInfo.  # noqa: E501
        :rtype: str
        """
        return self._municipality_id

    @municipality_id.setter
    def municipality_id(self, municipality_id):
        """Sets the municipality_id of this GeoLocationInfo.


        :param municipality_id: The municipality_id of this GeoLocationInfo.  # noqa: E501
        :type: str
        """

        self._municipality_id = municipality_id

    @property
    def admin_area_name(self):
        """Gets the admin_area_name of this GeoLocationInfo.  # noqa: E501


        :return: The admin_area_name of this GeoLocationInfo.  # noqa: E501
        :rtype: str
        """
        return self._admin_area_name

    @admin_area_name.setter
    def admin_area_name(self, admin_area_name):
        """Sets the admin_area_name of this GeoLocationInfo.


        :param admin_area_name: The admin_area_name of this GeoLocationInfo.  # noqa: E501
        :type: str
        """

        self._admin_area_name = admin_area_name

    @property
    def admin_area_id(self):
        """Gets the admin_area_id of this GeoLocationInfo.  # noqa: E501


        :return: The admin_area_id of this GeoLocationInfo.  # noqa: E501
        :rtype: str
        """
        return self._admin_area_id

    @admin_area_id.setter
    def admin_area_id(self, admin_area_id):
        """Sets the admin_area_id of this GeoLocationInfo.


        :param admin_area_id: The admin_area_id of this GeoLocationInfo.  # noqa: E501
        :type: str
        """

        self._admin_area_id = admin_area_id

    @property
    def country(self):
        """Gets the country of this GeoLocationInfo.  # noqa: E501


        :return: The country of this GeoLocationInfo.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this GeoLocationInfo.


        :param country: The country of this GeoLocationInfo.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def country_code(self):
        """Gets the country_code of this GeoLocationInfo.  # noqa: E501


        :return: The country_code of this GeoLocationInfo.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this GeoLocationInfo.


        :param country_code: The country_code of this GeoLocationInfo.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GeoLocationInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GeoLocationInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Summary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'registration_tid': 'int',
        'registration_name': 'str',
        'summaries': 'list[RegObsGenericValue]'
    }

    attribute_map = {
        'registration_tid': 'RegistrationTID',
        'registration_name': 'RegistrationName',
        'summaries': 'Summaries'
    }

    def __init__(self, registration_tid=None, registration_name=None, summaries=None):  # noqa: E501
        """Summary - a model defined in Swagger"""  # noqa: E501
        self._registration_tid = None
        self._registration_name = None
        self._summaries = None
        self.discriminator = None
        if registration_tid is not None:
            self.registration_tid = registration_tid
        if registration_name is not None:
            self.registration_name = registration_name
        if summaries is not None:
            self.summaries = summaries

    @property
    def registration_tid(self):
        """Gets the registration_tid of this Summary.  # noqa: E501


        :return: The registration_tid of this Summary.  # noqa: E501
        :rtype: int
        """
        return self._registration_tid

    @registration_tid.setter
    def registration_tid(self, registration_tid):
        """Sets the registration_tid of this Summary.


        :param registration_tid: The registration_tid of this Summary.  # noqa: E501
        :type: int
        """

        self._registration_tid = registration_tid

    @property
    def registration_name(self):
        """Gets the registration_name of this Summary.  # noqa: E501


        :return: The registration_name of this Summary.  # noqa: E501
        :rtype: str
        """
        return self._registration_name

    @registration_name.setter
    def registration_name(self, registration_name):
        """Sets the registration_name of this Summary.


        :param registration_name: The registration_name of this Summary.  # noqa: E501
        :type: str
        """

        self._registration_name = registration_name

    @property
    def summaries(self):
        """Gets the summaries of this Summary.  # noqa: E501


        :return: The summaries of this Summary.  # noqa: E501
        :rtype: list[RegObsGenericValue]
        """
        return self._summaries

    @summaries.setter
    def summaries(self, summaries):
        """Sets the summaries of this Summary.


        :param summaries: The summaries of this Summary.  # noqa: E501
        :type: list[RegObsGenericValue]
        """

        self._summaries = summaries

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Summary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Summary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
